<?php
/**
 * @connect_module_class_name CPayanyway
 * @package DynamicModules
 * @subpackage Payment
 */
// Модуль интеграции с платежной системой PayAnyWay

class CPayanyway extends PaymentModule
{

	var $assistant = "https://www.payanyway.ru/assistant.htm";
	var $type = PAYMTD_TYPE_ONLINE;
	var $unitId = '';
	var $accountId = '';
	var $additionalParameters = '';
	var $paymentModuleID = '';
	var $default_logo = './images_common/payment-icons/payanyway.png';
	
	function _initVars()
	{
		parent::_initVars();
		$this->title 		= PAW_PAYANYWAY_TTL;
		$this->description 	= PAW_PAYANYWAY_DSCR;
		$this->sort_order 	= 9;
		$this->Settings = array(
			'CONF_PAYANYWAY_MNTID',
			'CONF_PAYANYWAY_DATAINTEGRITYCODE',
			'CONF_PAYANYWAY_TRANS_CURRENCY',
			'CONF_PAYANYWAY_TESTMODE',
			'CONF_PAYANYWAY_ORDERSTATUS',
		);
		
		$ModuleConfigs = current(modGetModuleConfigs(get_class()));
		$this->paymentModuleID = isset($ModuleConfigs['ConfigID'])?$ModuleConfigs['ConfigID']:0;
	}
	
	function _initSettingFields()
	{
		$this->SettingsFields['CONF_PAYANYWAY_MNTID'] = array(
			'settings_value' 		=> '',
			'settings_title' 		=> PAW_CFG_MNT_ID_TTL,
			'settings_description' 	=> PAW_CFG_MNT_ID_DSCR,
			'settings_html_function'=> 'setting_TEXT_BOX(0,',
			'sort_order' 			=> 1,
		);
		$this->SettingsFields['CONF_PAYANYWAY_DATAINTEGRITYCODE'] = array(
			'settings_value' 		=> '',
			'settings_title' 		=> PAW_CFG_MNT_DATAINTEGRITY_CODE_TTL,
			'settings_description' 	=> PAW_CFG_MNT_DATAINTEGRITY_CODE_DSCR,
			'settings_html_function'=> 'setting_TEXT_BOX(0,',
			'sort_order' 			=> 1,
		);
        $this->SettingsFields['CONF_PAYANYWAY_TRANS_CURRENCY'] = array(
            'settings_value' 		=> '',
            'settings_title' 		=> PAW_CFG_MNT_CURRENCY_TTL,
            'settings_description' 	=> PAW_CFG_MNT_CURRENCY_DSCR,
            'settings_html_function'=> 'setting_CURRENCY_SELECT(',
        );
		$this->SettingsFields['CONF_PAYANYWAY_TESTMODE'] = array(
			'settings_value' 		=> '0',
			'settings_title' 		=> PAW_CFG_MNT_TEST_MODE_TTL,
			'settings_description' 	=> PAW_CFG_MNT_TEST_MODE_DSCR,
			'settings_html_function'=> 'setting_CHECK_BOX(',
			'sort_order' 			=> 1,
		);
		$this->SettingsFields['CONF_PAYANYWAY_ORDERSTATUS'] = array(
			'settings_value' 		=> '-1',
			'settings_title' 		=> PAW_CFG_MNT_ORDER_STATUS_TTL,
			'settings_description' 	=> PAW_CFG_MNT_ORDER_STATUS_DSCR,
			'settings_html_function'=> 'setting_SELECT_BOX(PaymentModule::_getStatuses(),',
			'sort_order' 			=> 1,
		);
	}

    function cleanProductName($value)
    {
        $result = preg_replace('/[^0-9a-zA-Zа-яА-Я ]/ui', '', htmlspecialchars_decode($value));
        $result = trim(mb_substr($result, 0, 20));
        return $result;
    }

    function after_processing_html( $orderID )
	{
		$action = $this->assistant;
        $mnt_id = (int)$this->_getSettingValue('CONF_PAYANYWAY_MNTID');
        $mnt_test_mode = (int)$this->_getSettingValue('CONF_PAYANYWAY_TESTMODE');
        $mnt_dataintegrity_code = $this->_getSettingValue('CONF_PAYANYWAY_DATAINTEGRITYCODE');
		$currency = currGetCurrencyByID($this->_getSettingValue('CONF_PAYANYWAY_TRANS_CURRENCY'));
        $mnt_currency_code = ($currency['currency_iso_3'] == "RUR") ? "RUB" : $currency['currency_iso_3'];
		$order = ordGetOrder($orderID);
        $amount = RoundFloatValue(PaymentModule::_convertCurrency($order['order_amount'], 0, $this->_getSettingValue('CONF_PAYANYWAY_TRANS_CURRENCY')));
		$order_amount = number_format($amount, 2, '.', '');
        $mnt_signature	 = md5("{$mnt_id}{$orderID}{$order_amount}{$mnt_currency_code}{$mnt_test_mode}{$mnt_dataintegrity_code}");
		
		if (!empty($this->unitId)) {
			$this->additionalParameters .= "<input type=hidden name=\"paymentSystem.unitId\" value=\"{$this->unitId}\">\n";
		}
		if (!empty($this->accountId)) {
			$this->additionalParameters .= "<input type=hidden name=\"paymentSystem.accountId\" value=\"{$this->accountId}\">\n";
		}

        $followup = (get_class($this) == "CPayanyway") ? "false" : "true";
		$res = "";
		$res .= 
			"<table width='100%'>\n".
			"	<tr>\n".
			"		<td align='center'>\n".
			"		<form method=\"POST\" action=\"{$action}\" name=\"payment\">\n".
			"		<input type=hidden name=\"MNT_ID\" value=\"{$mnt_id}\">\n".
			"		<input type=hidden name=\"MNT_TRANSACTION_ID\" value=\"{$orderID}\">\n".
			"		<input type=hidden name=\"MNT_CURRENCY_CODE\" value=\"{$mnt_currency_code}\">\n".
			"		<input type=hidden name=\"MNT_AMOUNT\" value=\"{$order_amount}\">\n".
			"		<input type=hidden name=\"MNT_SIGNATURE\" value=\"{$mnt_signature}\">\n".
					$this->additionalParameters.
			"		<input type=hidden name=\"MNT_SUCCESS_URL\" value=\"".getTransactionResultURL('success')."\">\n".
			"		<input type=hidden name=\"MNT_FAIL_URL\" value=\"".getTransactionResultURL('failure')."\">\n".
			"		<input type=hidden name=\"followup\" value=\"{$followup}\">\n".
			"		<input type=hidden name=\"javascriptEnabled\" value=\"{$followup}\">\n".
			"		<input type=submit value=\"Оплатить заказ в системе PayAnyWay сейчас!\"><br>\n".
			"		</form>\n".
			"		</td>\n".
			"	</tr>\n".
			"</table>";
			
		if (empty($this->additionalParameters)) {
			$res .= ' <script type="text/javascript">';
			$res .= 'document.payment.submit();';
			$res .= ' </script>';
		}
		return $res;
	}
	
	function transactionResultHandler($transaction_result = '',$message = '',$source = 'frontend')
	{
		switch($transaction_result){
			case 'callback':

				$integrityCode = '';
				$allConstants = get_defined_constants();
				if (is_array($allConstants) && count($allConstants)) {
					foreach ($allConstants AS $constKey => $constVal) {
						if (strpos($constKey, 'DATAINTEGRITYCODE') !== false && $constVal) {
							$integrityCode = $constVal;
							break;
						}
					}
				}
	
				$orderID = intval($_REQUEST['MNT_TRANSACTION_ID']);
				if ($orderID && ($order = _getOrderById($orderID))) {
					$params = '';
					if (isset($_REQUEST['MNT_COMMAND'])) $params .= $_REQUEST['MNT_COMMAND'];
					$params .= $_REQUEST['MNT_ID'] . $_REQUEST['MNT_TRANSACTION_ID'];
					if (isset($_REQUEST['MNT_OPERATION_ID'])) $params .= $_REQUEST['MNT_OPERATION_ID'];
					if (isset($_REQUEST['MNT_AMOUNT'])) $params .= $_REQUEST['MNT_AMOUNT'];
					$params .= $_REQUEST['MNT_CURRENCY_CODE'];
					if (isset($_REQUEST['MNT_SUBSCRIBER_ID'])) $params .= $_REQUEST['MNT_SUBSCRIBER_ID'];
					$params .= $_REQUEST['MNT_TEST_MODE'];
					$signature = md5($params . $integrityCode);

					if(strcasecmp($signature, $_REQUEST['MNT_SIGNATURE'] ) == 0) {

						$statusID = 0;
						if (is_array($allConstants) && count($allConstants)) {
							foreach ($allConstants AS $constKey => $constVal) {
								if (strpos($constKey, 'PAYANYWAY_ORDERSTATUS') !== false && $constVal) {
									$statusID = (int)$constVal;
									break;
								}
							}
						}

						if ($statusID) {
							$comment = sprintf('Заказ оплачен через PayAnyWay. Номер заказа - %d', $orderID);
							ostSetOrderStatusToOrder($_REQUEST['MNT_TRANSACTION_ID'], $statusID, $comment, 0, true);
						}


                        $orderID = $_REQUEST['MNT_TRANSACTION_ID'];
                        $order = ordGetOrder($orderID);

                        // данные для кассы
                        $inventory = array();
                        $kassa_customer = ($order && isset($order["customer_email"])) ? $order["customer_email"] : null;
                        $shipping_rate = ($order && isset($order["shipping_cost"])) ? $order["shipping_cost"] : null;
                        $kassa_delivery = ($shipping_rate > 0) ? $shipping_rate : null;
                        $order_content = ordGetOrderContent($orderID);
                        if (is_array($order_content) && count($order_content)) {
                            foreach ($order_content as $key => $val) {
                                $inventory[] = array("name" => trim(preg_replace("/&?[a-z0-9]+;/i", "", htmlspecialchars($val["name"]))), "price" => $val["Price"], "quantity" => $val["Quantity"], "vatTag" => 1105);
                            }
                        }

                        $kassa_inventory = (is_array($inventory) && count($inventory)) ? json_encode($inventory) : null;

                        if ($kassa_customer && $kassa_inventory) {
                            $resultCode = 200;
                            header("Content-type: application/xml");
                            $signature = md5($resultCode . $_REQUEST['MNT_ID'] . $_REQUEST['MNT_TRANSACTION_ID'] . $integrityCode);
                            $result = '<?xml version="1.0" encoding="UTF-8" ?>';
                            $result .= '<MNT_RESPONSE>';
                            $result .= '<MNT_ID>' . $_REQUEST['MNT_ID'] . '</MNT_ID>';
                            $result .= '<MNT_TRANSACTION_ID>' . $_REQUEST['MNT_TRANSACTION_ID'] . '</MNT_TRANSACTION_ID>';
                            $result .= '<MNT_RESULT_CODE>' . $resultCode . '</MNT_RESULT_CODE>';
                            $result .= '<MNT_SIGNATURE>' . $signature . '</MNT_SIGNATURE>';

                            if ($kassa_inventory || $kassa_customer || $kassa_delivery) {
                                $result .= '<MNT_ATTRIBUTES>';
                            }

                            if ($kassa_inventory) {
                                $result .= '<ATTRIBUTE>';
                                $result .= '<KEY>INVENTORY</KEY>';
                                $result .= '<VALUE>' . $kassa_inventory . '</VALUE>';
                                $result .= '</ATTRIBUTE>';
                            }

                            if ($kassa_customer) {
                                $result .= '<ATTRIBUTE>';
                                $result .= '<KEY>CUSTOMER</KEY>';
                                $result .= '<VALUE>' . $kassa_customer . '</VALUE>';
                                $result .= '</ATTRIBUTE>';
                            }

                            if ($kassa_delivery) {
                                $result .= '<ATTRIBUTE>';
                                $result .= '<KEY>DELIVERY</KEY>';
                                $result .= '<VALUE>' . $kassa_delivery . '</VALUE>';
                                $result .= '</ATTRIBUTE>';
                            }

                            if ($kassa_inventory || $kassa_customer || $kassa_delivery) {
                                $result .= '</MNT_ATTRIBUTES>';
                            }

                            $result .= '</MNT_RESPONSE>';

                            echo $result; exit;

                        }
                        else {
                            die("SUCCESS");
                        }

					}

				}
				die("FAIL");
				break;
			default:
				break;
		}
	}

}
?>